@@ -1,4 +1,3 @@
-import inspect
 import logging
 import time
 from collections import deque
@@ -15,7 +14,7 @@ from kamzik3 import WriteException, CommandFormatException, DeviceError
 from kamzik3.constants import *
 from kamzik3.devices.attribute import Attribute, SetFunction
 from kamzik3.devices.subject import Subject
-from kamzik3.snippets.snippetDataAccess import get_from_dict, fullname
+from kamzik3.snippets.snippetDataAccess import get_from_dict, fullname, is_equal
 from kamzik3.snippets.snippetsControlLoops import control_device_poller, control_device_connection_poller
 from kamzik3.snippets.snippetsGenerators import device_id_generator, token_generator
 from kamzik3.snippets.snippetsUnits import device_units
@@ -50,7 +49,6 @@ class Device(Subject, YamlSerializable):
     connection_timeout = 4000
     response_timeout = 4000
     allow_reconnect = True
-    device_server = None
     session = None
     # Maximum number of commands joined in one request
     max_command_retry = 0
@@ -149,8 +147,32 @@ class Device(Subject, YamlSerializable):
             if group not in self.attributes:
                 self.attributes[group] = {}
             self.attributes[group][name] = attribute
+        if kamzik3.session.publisher is not None:
+            header = "{}.{}".format(attribute.attribute_id, TOKEN_ATTRIBUTE_REPLACE)
+            kamzik3.session.publisher.push_message(header, attribute)
         return attribute
 
+    def delete_attribute(self, name, group=None):
+        attribute_path = name
+        if group is not None:
+            attribute_path = "{}.{}".format(group, attribute_path)
+        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
+        if group is not None:
+            del self.attributes[group][name]
+        else:
+            del self.attributes[name]
+        if kamzik3.session.publisher is not None:
+            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_DELETE)
+            kamzik3.session.publisher.push_message(header, attribute_path)
+
+    def delete_attribute_group(self, group):
+        attribute_path = group
+        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
+        del self.attributes[group]
+        if kamzik3.session.publisher is not None:
+            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_GROUP_DELETE)
+            kamzik3.session.publisher.push_message(header, attribute_path)
+
     def add_attribute(self, name, attribute, group=None):
         attribute_list = [name]
         if group is None:
@@ -163,9 +185,9 @@ class Device(Subject, YamlSerializable):
 
         attribute_exists = attribute.attribute_id in self.attributes_sharing_map
         self.attributes_sharing_map[attribute.attribute_id] = attribute_list
-        if attribute_exists and self.device_server is not None:
+        if attribute_exists and kamzik3.session.publisher is not None:
             header = "{}.{}".format(attribute.attribute_id, TOKEN_ATTRIBUTE_REPLACE)
-            self.device_server.push_message(header, attribute)
+            kamzik3.session.publisher.push_message(header, attribute)
         return attribute
 
     def share_group(self, source_device, source_group, target_group, attribute_name_mask=None):
@@ -267,7 +289,7 @@ class Device(Subject, YamlSerializable):
                 if (attribute, callback) in self.attribute_attach_map[attribute_object.attribute_id]:
                     self.attribute_attach_map[attribute_object.attribute_id].remove((attribute, callback))
             except KeyError:
-                pass # Callback does not exists
+                pass  # Callback does not exists
 
         except (KeyError, AttributeError):
             if self.logger is not None:
@@ -371,7 +393,7 @@ class Device(Subject, YamlSerializable):
         This sets Device attribute.
         Use this function when You want to set attribute by tuple or list key.
         Example: Device.set((ATTR_STATUS, VALUE), STATUS_IDLE)
-        Attribute value is pushed into server if Device is connected on any.
+        Attribute value is pushed into server if Device is connected listed on one.
         To reduce amount of pushed attributes we check if value is different from previous one.
         :param attribute: list
         :param value: mixed
@@ -392,9 +414,10 @@ class Device(Subject, YamlSerializable):
 
         if propagate_change:
             value = attribute_object[attribute_list[-1]]
-            if value != current_value and self.device_server is not None:
+
+            if not is_equal(current_value, value) and kamzik3.session.publisher is not None:
                 header = "{}.{}".format(attribute_object.attribute_id, attribute_list[-1])
-                self.device_server.push_message(header, value)
+                kamzik3.session.publisher.push_message(header, value, min_timeout=attribute_object.min_stream_timeout)
 
         return set_token
 
@@ -607,17 +630,6 @@ class Device(Subject, YamlSerializable):
         """
         return self.get_value(ATTR_STATUS) in statuses
 
-    def set_device_server(self, device_server):
-        """
-        Set device server
-        :param device_server: DeviceServer
-        :return: None
-        """
-        self.device_server = device_server
-
-    def clear_device_server(self):
-        self.device_server = None
-
     def stop_polling(self):
         """
         Remove Device from device_poller loop.
@@ -678,8 +690,6 @@ class Device(Subject, YamlSerializable):
         :return:
         """
         self.disconnect()
-        if self.device_server is not None:
-            self.device_server.remove_device(self)
 
         if self.logger is not None:
             for handler in self.logger.handlers[:]:
@@ -728,7 +738,10 @@ class Device(Subject, YamlSerializable):
         :param commands: list of command to be send
         :return: list of NOT sent commands
         """
+        if not self.accepting_commands():
+            return commands
         try:
+            mark = time.time()
             if self.connected:
                 command_string = u""
                 commands_to_push_counter = 0
@@ -741,9 +754,9 @@ class Device(Subject, YamlSerializable):
                         command_string = command_string[:-len(command[0])]
                         break
                     if command[3]:  # If command is returning
-                        self.commands_buffer.append((command, time.time()))
+                        self.commands_buffer.append((command, mark))
                     else:  # Command is not returning, simulate immediate execution
-                        self.response_timestamp = time.time()
+                        self.response_timestamp = mark
                     if commands_to_push_counter >= self.push_commands_max:
                         break
                 self.push(command_string.encode())
@@ -756,22 +769,6 @@ class Device(Subject, YamlSerializable):
         finally:
             return commands
 
-    def retry_command(self):
-        """
-        Retry to send command.
-        :return: bool
-        """
-        if self.command_retry_count < self.max_command_retry:
-            waiting_commands = self.commands_buffer.copy()
-            self.commands_buffer = deque()
-            for command in waiting_commands:
-                self.device_poller.prepare_command(self, command[0])
-            self.response_timestamp = time.time()
-            self.command_retry_count += 1
-            return True
-        else:
-            return False
-
     def accepting_commands(self):
         """
         Check if device is ready to send another commands.
@@ -915,6 +912,9 @@ class Device(Subject, YamlSerializable):
             return False
         time_diff = self.request_timestamp - self.response_timestamp
         if time_diff >= self.response_timeout * 1e-3:
+            print(self.device_id, time_diff, self.request_timestamp, self.response_timestamp,
+                  self.response_timeout * 1e-3)
+            print(len(self.commands_buffer), self.commands_buffer)
             self.handle_response_error(u"Response timeout")
             return False
         return True
