@@ -1,5 +1,6 @@
 import os
 import time
+from collections import OrderedDict
 from copy import copy
 from multiprocessing import Process
 from threading import Thread
@@ -447,7 +448,7 @@ class DeviceFileServer(Device, BalancedServer, Thread):
         """
         self.set_value([task_id, ATTR_STATUS], STATUS_BUSY)
         requested_files = self.get_value([task_id, ATTR_REQUESTED_FILES])
-        synced_files = {}
+        synced_files = OrderedDict()
 
         for drive, path in self.get_value([task_id, ATTR_REQUESTED_FILES]):
             input_dir, file_name = os.path.split(path)
