@@ -5,12 +5,11 @@ from threading import Thread
 
 import numpy as np
 import serial
-
+import kamzik3
 from kamzik3.constants import *
 from kamzik3.devices.device import Device
 from kamzik3.devices.devicePort import DevicePort
 from kamzik3.devices.deviceSocket import DeviceSocket
-from kamzik3.snippets.snippetsControlLoops import DevicePoller
 from kamzik3.snippets.snippetsDecorators import expose_method
 
 
@@ -94,8 +93,8 @@ class DeviceGalil(DeviceSocket):
             self.logger.info(u"Device configuration took {} sec.".format(time.time() - start_at))
 
         self.command("EO 0;")
+
         if self.udp_port is not None:
-            self.command("IHC=>-1;")  # Disconnect any UDP connection on C interface
             self.command("IHC={} <{} >1;".format(self.udp_host.replace(".", ","),
                                                  self.udp_port))  # Set UDP connection to provided host and port
             self.command("CFC;")  # Set interface C as main output for any UDP packet
@@ -142,7 +141,8 @@ class DeviceGalil(DeviceSocket):
                         ao_attribute[MIN]), ao_attribute.remove_offset_factor(ao_attribute[MAX])
                     dt_info = np.iinfo(self.analog_output_date_type[index])
                     self.set_raw_value(("Analog output", self.AO_config[index]),
-                                   (((ao - dt_info.min) * (ao_max - ao_min)) / (dt_info.max - dt_info.min)) + ao_min)
+                                       (((ao - dt_info.min) * (ao_max - ao_min)) / (
+                                                   dt_info.max - dt_info.min)) + ao_min)
 
                 for index, ai in enumerate(np.frombuffer(data[24:40], dtype=self.analog_input_date_type)[0]):
                     ai_attribute = self["Analog input"][self.AI_config[index]]
@@ -150,7 +150,8 @@ class DeviceGalil(DeviceSocket):
                         ai_attribute[MIN]), ai_attribute.remove_offset_factor(ai_attribute[MAX])
                     dt_info = np.iinfo(self.analog_input_date_type[index])
                     self.set_raw_value(("Analog input", self.AI_config[index]),
-                                   (((ai - dt_info.min) * (ai_max - ai_min)) / (dt_info.max - dt_info.min)) + ai_min)
+                                       (((ai - dt_info.min) * (ai_max - ai_min)) / (
+                                                   dt_info.max - dt_info.min)) + ai_min)
 
                 digital_output = format(np.frombuffer(data[40:42], dtype=np.ushort)[0], "b")
                 digital_input = format(np.frombuffer(data[42:44], dtype=np.ushort)[0], "b")
@@ -168,9 +169,9 @@ class DeviceGalil(DeviceSocket):
     def start_polling(self):
         if self.udp_port is None:
             Device.start_polling(self)
-            self.poll_command(self.analog_input_readout_command, 300)
-            self.poll_command(self.analog_output_readout_command, 300)
-            self.poll_command(self.digital_lO_readout_command, 300)
+            self.poll_command(self.analog_input_readout_command, 200)
+            self.poll_command(self.analog_output_readout_command, 200)
+            self.poll_command(self.digital_lO_readout_command, 200)
 
     def handle_readout(self, readout_buffer):
         command, output, callback, token = super(DeviceGalil, self).handle_readout(readout_buffer)
@@ -236,7 +237,7 @@ class DeviceGalil(DeviceSocket):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
 
         return command, output, callback, token
 
