@@ -4,7 +4,7 @@ from threading import Thread
 import numpy as np
 import serial
 from bidict import frozenbidict
-
+import kamzik3
 from kamzik3 import DeviceError, units
 from kamzik3.constants import *
 from kamzik3.devices.device import Device
@@ -171,11 +171,11 @@ class DeviceGalilMotor(DeviceGalil):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
 
             for observer in self._observers[:]:
                 if isinstance(observer, DeviceGalilMotorChannel):
-                    self.device_server.push_message(observer.device_id, [command, readout_buffer], token)
+                    kamzik3.session.publisher.push_message(observer.device_id, [command, readout_buffer], token)
 
     def get_motor_config(self, callback=None):
         self.command(u"MG _CN0, _CN1, _CN2, _CN3, _CN4;", callback)
@@ -403,18 +403,6 @@ class DeviceGalilMotorChannel(DeviceChannel):
     def get_status(self, callback=None):
         self.command(u"MG _TS{};".format(self.acronym), callback)
 
-    def get_low_current_stepper_mode(self, callback=None):
-        self.command(u"MG _LC{};".format(self.acronym), callback)
-
-    def get_acceleration(self, callback=None):
-        self.command(u"MG _AC{};".format(self.acronym), callback)
-
-    def get_deceleration(self, callback=None):
-        self.command(u"MG _DC{};".format(self.acronym), callback)
-
-    def get_position(self):
-        self.command(u"TD{};".format(self.acronym))
-
     def begin_motion(self):
         self.command(u"BG{};".format(self.acronym))
 
