@@ -5,9 +5,9 @@ from time import sleep
 import numpy as np
 from karabo_bridge import Client as KbClient
 
+import kamzik3
 from kamzik3 import units, DeviceError
 from kamzik3.constants import *
-from kamzik3.devices.attribute import Attribute
 from kamzik3.devices.device import Device
 from kamzik3.snippets.snippetDataAccess import get_from_dict, set_in_dict
 from kamzik3.snippets.snippetsDecorators import expose_method
@@ -127,8 +127,8 @@ class DeviceKaraboBridge(Device):
                 value = self.attributes[attribute]
             token = "{}.{}".format(TOKEN_ATTRIBUTE, attribute)
 
-        if token and self.device_server is not None and not isinstance(value, np.ndarray):
-            self.device_server.push_message(self.device_id, (attribute, value), token)
+        if token and kamzik3.session.publisher is not None and not isinstance(value, np.ndarray):
+            kamzik3.session.publisher.push_message(self.device_id, (attribute, value), token)
 
     def command(self, command, callback=None, with_token=False, returning=True):
         raise DeviceError("Device does not accept any commands.")
