@@ -1,5 +1,6 @@
 import logging
 import os
+import shutil
 import time
 from collections import OrderedDict
 
@@ -16,6 +17,7 @@ from kamzik3.devices.general.measurementGroup import MeasurementGroup
 from kamzik3.snippets.snippetLogging import set_rotating_file_handler, set_sys_exception_handler, get_console_handler
 from kamzik3.snippets.snippetsControlLoops import control_asyncore_loop, control_device_poller, control_port_read_loop, \
     control_device_connection_poller
+from kamzik3.snippets.snippetsDecorators import expose_method
 from kamzik3.snippets.snippetsTimer import CallbackTimer
 
 
@@ -365,7 +367,11 @@ class DeviceSession(Device):
         control_device_connection_poller.stop()
 
     def set_high_process_priority(self):
-        """ Set the priority of the process to below-normal."""
+        """
+        Set high process affinity.
+        In Windows use win32process.REALTIME_PRIORITY_CLASS, for Linux change nice to -20.
+        :return: None
+        """
         if psutil.WINDOWS:
             try:
                 import win32api, win32process, win32con
@@ -381,3 +387,20 @@ class DeviceSession(Device):
                 process.nice(-20)
             except psutil.AccessDenied as e:
                 self.logger.error("Could not raise process priority")
+
+    @expose_method()
+    def clear_cache_folder(self):
+        """
+        Clear all files from current '.cache' folder.
+        :return:
+        """
+        folder = self.get_value(ATTR_CACHE_DIRECTORY)
+        for filename in os.listdir(folder):
+            file_path = os.path.join(folder, filename)
+            try:
+                if os.path.isfile(file_path) or os.path.islink(file_path):
+                    os.unlink(file_path)
+                elif os.path.isdir(file_path):
+                    shutil.rmtree(file_path)
+            except Exception as e:
+                self.logger.error('Failed to delete %s. Reason: %s' % (file_path, e))
