@@ -4,6 +4,7 @@ import numpy as np
 from bidict import frozenbidict
 from pint import UndefinedUnitError
 
+import kamzik3
 from kamzik3 import units, DeviceUnitError
 from kamzik3.constants import *
 from kamzik3.devices.deviceChannel import DeviceChannel
@@ -201,10 +202,10 @@ class DeviceSmarpodEcm(DeviceSocket):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
             for observer in self._observers[:]:
                 if isinstance(observer, DeviceSmarpodEcmChannel):
-                    self.device_server.push_message(observer.device_id, [command, readout_buffer], token)
+                    kamzik3.session.publisher.push_message(observer.device_id, [command, readout_buffer], token)
 
     def start_polling(self):
         super().start_polling()
