@@ -125,14 +125,17 @@ class DeviceVirtualDirectory(DeviceFileServer):
         :return:
         """
         prepared_files = []
+        metadata = dict()
         for drive, file_path in input_files:
             if not self.on_fs(drive, file_path):
                 drive_meta = self.get_value(ATTR_DRIVES)[drive]
                 source = drive_meta["source"]
-                prepared_files += source.prepare_files(input_files=[(drive, file_path)])
+                source_prepared_files, source_metadata = source.prepare_files(input_files=[(drive, file_path)])
+                prepared_files += source_prepared_files
+                metadata.update(source_metadata)
             else:
                 prepared_files.append((drive, file_path))
-        return prepared_files
+        return prepared_files, metadata
 
     def sync_files(self, requested_files):
         """
@@ -140,8 +143,9 @@ class DeviceVirtualDirectory(DeviceFileServer):
         :param requested_files:
         :return:
         """
-        requested_files = set([tuple(f) for f in requested_files])
+        # requested_files = set([tuple(f) for f in requested_files])
         sync_parts = [INSTRUCTION_SYNC, str(len(requested_files)).encode()]
+        # sync_parts = [x for x in requested_files if x not in sync_parts]
         for drive, file_path in requested_files:
             sync_parts += [drive.encode(), file_path.encode()]
         self.frontend_connector.send_multipart(sync_parts)
