@@ -1,4 +1,5 @@
-from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QPalette, QColor
 from PyQt5.QtWidgets import QCheckBox, QSizePolicy
 
 from kamzik3.constants import *
@@ -11,11 +12,13 @@ class AttributeBoolWidget(AttributeWidget):
     def _set_input_widget(self):
         self.input_widget = QCheckBox()
         self.input_widget.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
-        self.input_widget.setStyleSheet(".QCheckBox:checked {color: green} .QCheckBox:unchecked {color: red}")
+        self.input_widget.setStyleSheet("QCheckBox:checked {color: green} QCheckBox:unchecked {color: red}")
         self.input_widget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.input_widget.clicked.connect(self.clicked)
         if self.attribute[READONLY]:
-            self.input_widget.setDisabled(True)
+            self.input_widget.setAttribute(Qt.WA_TransparentForMouseEvents)
+            self.input_widget.setFocusPolicy(Qt.NoFocus)
+
 
     def clicked(self, flag):
         self.input_widget.setText("On" if flag else "Off")
@@ -33,7 +36,3 @@ class AttributeBoolWidget(AttributeWidget):
 
     def get_widget_value(self):
         return self.input_widget.isChecked()
-
-    @pyqtSlot("QString")
-    def set_unit(self, unit=None, reset=False):
-        return
