@@ -1,8 +1,13 @@
-import time
+import os
+import re
 
 from PyQt5.QtCore import Qt, pyqtSlot, QItemSelection, QItemSelectionModel, QDateTime
-from PyQt5.QtWidgets import QWidget, QMdiSubWindow
+from PyQt5.QtWidgets import QWidget, QMdiSubWindow, QFileDialog
+from pyqtgraph import exporters
+from reportlab.platypus import SimpleDocTemplate, Image, LayoutError
 
+import kamzik3
+from kamzik3.constants import ATTR_CACHE_DIRECTORY
 from kamzik3.gui.deviceWidget import DeviceWidget
 from kamzik3.gui.logReader.logPlotView import LogPlotView, LogPlotViewMaster, QMdiSubWindowPlot
 from kamzik3.gui.logReader.logViewHeaderModel import LogViewHeaderModel, LogHeaderSelectionModel
@@ -39,7 +44,7 @@ class LogView(Ui_Form, DeviceWidget):
         # Connect activated sub-window to self.slot_window_activated method
         self.mdi_area.subWindowActivated.connect(self.slot_window_activated)
 
-    def open(self, path, append=False, refresh=True):
+    def open(self, path, append=False, refresh=True, filter=None):
         """
         Open logfile.
         should be replaced.
@@ -47,8 +52,7 @@ class LogView(Ui_Form, DeviceWidget):
         :return:
         """
         try:
-            a = time.time()
-            padas_dt = self.device.parse(path=path, format="mag_log")
+            padas_dt = self.device.parse(path=path, format="mag_log", filter=filter)
             if append:
                 self.pandas_dt = self.pandas_dt.append(padas_dt)
             else:
@@ -421,6 +425,19 @@ class LogView(Ui_Form, DeviceWidget):
             self.master_zoom_changed(self.master_window.widget().lookingGlass.getRegion())
         self.view_tiled = True
 
+    def slot_select_rows(self, rows=None):
+        if rows is None:
+            return
+
+        selection_model = self.input_header_items.selectionModel()
+        model = self.input_header_items.model()
+        for row_data in reversed(rows):
+            index = model.model_data.index(row_data)
+            if index > 0:
+                selection = QItemSelection(model.createIndex(index, 0), model.createIndex(index, 0))
+                selection_model.select(selection, QItemSelectionModel.Select | QItemSelectionModel.Rows)
+        self.slot_selection_changed()
+
     @pyqtSlot(bool)
     def slot_set_windowed_plots(self, flag):
         """
@@ -463,3 +480,37 @@ class LogView(Ui_Form, DeviceWidget):
         """
         if flag:
             self.tile_sub_windows()
+
+    def slot_export_to_pdf(self):
+        plot_width, plot_height = self.input_plot_width.value(), self.input_plot_height.value()
+        options = QFileDialog.Options()
+        options |= QFileDialog.DontUseNativeDialog
+        extension_filter = "pdf [*.pdf] (*.pdf)"
+        file_path, _ = QFileDialog.getSaveFileName(self, 'Set output file', "./{}".format("output.pdf"),
+                                                   filter=extension_filter, initialFilter=extension_filter,
+                                                   options=options)
+        if file_path != "":
+            parts = []
+            cache_dir = kamzik3.session.get_value(ATTR_CACHE_DIRECTORY)
+            for index, window in enumerate(reversed(self.mdi_area.subWindowList())):
+                actual_size = window.widget().size()
+                window.widget().resize(plot_width, plot_height)
+                exporter = exporters.ImageExporter(window.widget().plotItem)
+                exporter.parameters()['width'] = plot_width
+                img_path = os.path.join(cache_dir, 'img{}.png'.format(index))
+                exporter.export(img_path)
+                parts.append(Image(img_path))
+                window.widget().resize(actual_size)
+
+            while True:
+                try:
+                    use_parts = parts.copy()
+                    report = SimpleDocTemplate(file_path, pagesize=(plot_width, plot_height))
+                    report.build(use_parts)
+                    break
+                except LayoutError as e:
+                    pw, ph = re.findall('([\-0-9\.]+)\sx\s([\-0-9\.]+)', str(e))[0]
+                    plot_width += abs(plot_width - float(pw))
+                    plot_height += abs(plot_height - float(ph))
+                except Exception as e:
+                    show_error_message("Export error: {}".format(e), self)
